# whitecanvas.canvas

::: whitecanvas.canvas
    options:
        show_signature_annotations: false
        heading_level: 4

::: whitecanvas.canvas._namespaces
    options:
        show_signature_annotations: false
        heading_level: 4
